@@ -1,4 +1,3 @@
-import codecs
 import os
 import shutil
 import sys
@@ -48,7 +47,9 @@ def save_test_failure_data(test, name, folder=None):
         failure_data_file_path = os.path.join(file_path, name)
     else:
         failure_data_file_path = name
-    failure_data_file = codecs.open(failure_data_file_path, "w+", "utf-8")
+    failure_data_file = open(
+        failure_data_file_path, mode="w+", encoding="utf-8"
+    )
     data_to_save = []
     if not hasattr(sb_config, "_report_test_id"):
         exc_message = "(Unknown Exception)"
@@ -100,7 +101,7 @@ def process_failures(test, test_count, duration):
     bad_page_data = "failure_%s.txt" % test_count
     screenshot_path = os.path.join(LATEST_REPORT_DIR, bad_page_image)
     if hasattr(test, "_last_page_screenshot") and test._last_page_screenshot:
-        with open(screenshot_path, "wb") as file:
+        with open(screenshot_path, mode="wb") as file:
             file.write(test._last_page_screenshot)
     save_test_failure_data(test, bad_page_data, folder=LATEST_REPORT_DIR)
     exc_message = None
@@ -173,7 +174,7 @@ def add_bad_page_log_file(page_results_list):
     abs_path = os.path.abspath(".")
     file_path = os.path.join(abs_path, LATEST_REPORT_DIR)
     log_file = os.path.join(file_path, RESULTS_TABLE)
-    f = open(log_file, "w")
+    f = open(log_file, mode="w")
     h_p1 = '"Num","Result","Stacktrace","Screenshot",'
     h_p2 = '"URL","Browser","Epoch Time","Duration",'
     h_p3 = '"Test Case Address","Additional Info"\n'
@@ -198,7 +199,7 @@ def add_results_page(html):
     file_path = os.path.join(abs_path, LATEST_REPORT_DIR)
     results_file_name = HTML_REPORT
     results_file = os.path.join(file_path, results_file_name)
-    f = open(results_file, "w")
+    f = open(results_file, mode="w")
     f.write(html)
     f.close()
     return results_file
