@@ -387,6 +387,20 @@ class ValidBrowsers:
         "ie",
         "safari",
         "remote",
+        "opera",
+        "brave",
+        "comet",
+        "atlas",
+    ]
+
+
+class ChromiumSubs:
+    # Chromium browsers that still use chromedriver
+    chromium_subs = [
+        "opera",
+        "brave",
+        "comet",
+        "atlas",
     ]
 
 
@@ -406,7 +420,14 @@ class ValidBinaries:
         "brave",
         "opera",
         "opera-stable",
+        "comet",
+        "comet-browser",
+        "comet-stable",
+        "atlas",
+        "atlas-browser",
+        "atlas-stable",
         "chrome.exe",  # WSL (Windows Subsystem for Linux)
+        "chromium.exe",  # WSL (Windows Subsystem for Linux)
     ]
     valid_edge_binaries_on_linux = [
         "microsoft-edge",
@@ -423,7 +444,13 @@ class ValidBinaries:
         "Google Chrome Beta",
         "Google Chrome Dev",
         "Brave Browser",
+        "Brave",
+        "Opera Browser",
         "Opera",
+        "Comet Browser",
+        "Comet",
+        "Atlas Browser",
+        "Atlas",
     ]
     valid_edge_binaries_on_macos = [
         "Microsoft Edge",
@@ -434,6 +461,8 @@ class ValidBinaries:
         "chrome-headless-shell.exe",
         "brave.exe",
         "opera.exe",
+        "comet.exe",
+        "atlas.exe",
     ]
     valid_edge_binaries_on_windows = [
         "msedge.exe",
