@@ -17,7 +17,6 @@ By.XPATH               # "xpath"
 By.TAG_NAME            # "tag name"
 By.PARTIAL_LINK_TEXT   # "partial link text"
 """
-import codecs
 import os
 import time
 from contextlib import suppress
@@ -1531,7 +1530,7 @@ def save_page_source(driver, name, folder=None):
     rendered_source = log_helper.get_html_source_with_base_href(
         driver, page_source
     )
-    html_file = codecs.open(html_file_path, "w+", "utf-8")
+    html_file = open(html_file_path, "w+", "utf-8")
     html_file.write(rendered_source)
     html_file.close()
 
