@@ -1,9 +1,11 @@
 """Selenium Plugin for SeleniumBase tests that run with pynose / nosetests"""
+import os
 import sys
 from contextlib import suppress
 from nose.plugins import Plugin
 from seleniumbase import config as sb_config
 from seleniumbase.config import settings
+from seleniumbase.core import detect_b_ver
 from seleniumbase.core import proxy_helper
 from seleniumbase.fixtures import constants
 from seleniumbase.fixtures import shared_utils
@@ -16,6 +18,10 @@ class SeleniumBrowser(Plugin):
     --edge  (Shortcut for "--browser=edge".)
     --firefox  (Shortcut for "--browser=firefox".)
     --safari  (Shortcut for "--browser=safari".)
+    --opera  (Shortcut for "--browser=opera".)
+    --brave  (Shortcut for "--browser=brave".)
+    --comet  (Shortcut for "--browser=comet".)
+    --atlas  (Shortcut for "--browser=atlas".)
     --cft  (Shortcut for using `Chrome for Testing`)
     --chs  (Shortcut for using `Chrome-Headless-Shell`)
     --user-data-dir=DIR  (Set the Chrome user data directory to use.)
@@ -146,6 +152,34 @@ class SeleniumBrowser(Plugin):
             default=False,
             help="""Shortcut for --browser=safari""",
         )
+        parser.addoption(
+            "--opera",
+            action="store_true",
+            dest="use_opera",
+            default=False,
+            help="""Shortcut for --browser=opera""",
+        )
+        parser.addoption(
+            "--brave",
+            action="store_true",
+            dest="use_brave",
+            default=False,
+            help="""Shortcut for --browser=brave""",
+        )
+        parser.addoption(
+            "--comet",
+            action="store_true",
+            dest="use_comet",
+            default=False,
+            help="""Shortcut for --browser=comet""",
+        )
+        parser.addoption(
+            "--atlas",
+            action="store_true",
+            dest="use_atlas",
+            default=False,
+            help="""Shortcut for --browser=atlas""",
+        )
         parser.addoption(
             "--cft",
             action="store_true",
@@ -1057,6 +1091,11 @@ class SeleniumBrowser(Plugin):
         browser_set = None
         browser_text = None
         browser_list = []
+        # Check if binary-location in options
+        bin_loc_in_options = False
+        for arg in sys_argv:
+            if arg in ["--binary-location", "--binary_location", "--bl"]:
+                bin_loc_in_options = True
         if "--browser=chrome" in sys_argv or "--browser chrome" in sys_argv:
             browser_changes += 1
             browser_set = "chrome"
@@ -1081,6 +1120,46 @@ class SeleniumBrowser(Plugin):
             browser_changes += 1
             browser_set = "remote"
             browser_list.append("--browser=remote")
+        if "--browser=opera" in sys_argv or "--browser opera" in sys_argv:
+            if not bin_loc_in_options:
+                bin_loc = detect_b_ver.get_binary_location("opera")
+                if os.path.exists(bin_loc):
+                    browser_changes += 1
+                    browser_set = "opera"
+                    sb_config._browser_shortcut = "opera"
+                    sb_config._cdp_browser = "opera"
+                    sb_config._cdp_bin_loc = bin_loc
+                    browser_list.append("--browser=opera")
+        if "--browser=brave" in sys_argv or "--browser brave" in sys_argv:
+            if not bin_loc_in_options:
+                bin_loc = detect_b_ver.get_binary_location("brave")
+                if os.path.exists(bin_loc):
+                    browser_changes += 1
+                    browser_set = "brave"
+                    sb_config._browser_shortcut = "brave"
+                    sb_config._cdp_browser = "brave"
+                    sb_config._cdp_bin_loc = bin_loc
+                    browser_list.append("--browser=brave")
+        if "--browser=comet" in sys_argv or "--browser comet" in sys_argv:
+            if not bin_loc_in_options:
+                bin_loc = detect_b_ver.get_binary_location("comet")
+                if os.path.exists(bin_loc):
+                    browser_changes += 1
+                    browser_set = "comet"
+                    sb_config._browser_shortcut = "comet"
+                    sb_config._cdp_browser = "comet"
+                    sb_config._cdp_bin_loc = bin_loc
+                    browser_list.append("--browser=comet")
+        if "--browser=atlas" in sys_argv or "--browser atlas" in sys_argv:
+            if not bin_loc_in_options:
+                bin_loc = detect_b_ver.get_binary_location("atlas")
+                if os.path.exists(bin_loc):
+                    browser_changes += 1
+                    browser_set = "atlas"
+                    sb_config._browser_shortcut = "atlas"
+                    sb_config._cdp_browser = "atlas"
+                    sb_config._cdp_bin_loc = bin_loc
+                    browser_list.append("--browser=atlas")
         browser_text = browser_set
         if "--chrome" in sys_argv and not browser_set == "chrome":
             browser_changes += 1
@@ -1107,6 +1186,46 @@ class SeleniumBrowser(Plugin):
             browser_text = "safari"
             sb_config._browser_shortcut = "safari"
             browser_list.append("--safari")
+        if "--opera" in sys_argv and not browser_set == "opera":
+            if not bin_loc_in_options:
+                bin_loc = detect_b_ver.get_binary_location("opera")
+                if os.path.exists(bin_loc):
+                    browser_changes += 1
+                    browser_text = "opera"
+                    sb_config._browser_shortcut = "opera"
+                    sb_config._cdp_browser = "opera"
+                    sb_config._cdp_bin_loc = bin_loc
+                    browser_list.append("--opera")
+        if "--brave" in sys_argv and not browser_set == "brave":
+            if not bin_loc_in_options:
+                bin_loc = detect_b_ver.get_binary_location("brave")
+                if os.path.exists(bin_loc):
+                    browser_changes += 1
+                    browser_text = "brave"
+                    sb_config._browser_shortcut = "brave"
+                    sb_config._cdp_browser = "brave"
+                    sb_config._cdp_bin_loc = bin_loc
+                    browser_list.append("--brave")
+        if "--comet" in sys_argv and not browser_set == "comet":
+            if not bin_loc_in_options:
+                bin_loc = detect_b_ver.get_binary_location("comet")
+                if os.path.exists(bin_loc):
+                    browser_changes += 1
+                    browser_text = "comet"
+                    sb_config._browser_shortcut = "comet"
+                    sb_config._cdp_browser = "comet"
+                    sb_config._cdp_bin_loc = bin_loc
+                    browser_list.append("--comet")
+        if "--atlas" in sys_argv and not browser_set == "atlas":
+            if not bin_loc_in_options:
+                bin_loc = detect_b_ver.get_binary_location("atlas")
+                if os.path.exists(bin_loc):
+                    browser_changes += 1
+                    browser_text = "atlas"
+                    sb_config._browser_shortcut = "atlas"
+                    sb_config._cdp_browser = "atlas"
+                    sb_config._cdp_bin_loc = bin_loc
+                    browser_list.append("--atlas")
         if browser_changes > 1:
             message = "\n\n  TOO MANY browser types were entered!"
             message += "\n  There were %s found:\n  >  %s" % (
@@ -1183,6 +1302,8 @@ class SeleniumBrowser(Plugin):
         if sb_config._browser_shortcut:
             self.options.browser = sb_config._browser_shortcut
             test.test.browser = sb_config._browser_shortcut
+        if test.test.browser in constants.ChromiumSubs.chromium_subs:
+            test.test.browser = "chrome"  # Still uses chromedriver
         test.test.cap_file = self.options.cap_file
         test.test.cap_string = self.options.cap_string
         test.test.headless = self.options.headless
@@ -1219,6 +1340,8 @@ class SeleniumBrowser(Plugin):
         test.test.extension_dir = self.options.extension_dir
         test.test.disable_features = self.options.disable_features
         test.test.binary_location = self.options.binary_location
+        if hasattr(sb_config, "_cdp_bin_loc") and sb_config._cdp_bin_loc:
+            test.test.binary_location = sb_config._cdp_bin_loc
         if self.options.use_cft and not test.test.binary_location:
             test.test.binary_location = "cft"
         elif self.options.use_chs and not test.test.binary_location:
